ATInit class

Constructors

ATInit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aANDROID() → String
aAppVersionCodeKey() → String
aAppVersionNameKey() → String
aBrandKey() → String
aGAID() → String
aIDFAKey() → String
aIDFVKey() → String
aIMEI() → String
aINSTALLER() → String
aLanguageKey() → String
aMAC() → String
aMCCKey() → String
aMNCKey() → String
aModelKey() → String
aNetworkTypeKey() → String
aOAID() → String
aOrientKey() → String
aPackageNameKey() → String
aScreenKey() → String
aTimeZoneKey() → String
aUserAgentKey() → String
aVersionCodeKey() → String
aVersionNameKey() → String
dataConsentSetNonpersonalized() → String
dataConsentSetPersonalized() → String
dataConsentSetUnknown() → String
deniedUploadDeviceInfo({List<String>? deniedUploadDeviceInfoList}) → Future<List>
getGDPRLevel() → Future<String>
getUserLocation() → Future<String>
initAnyThinkSDK({required String appidStr, required String appidkeyStr}) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setChannelStr({String? channelStr}) → Future<String>
setCustomDataMap({Map<String, Object>? customDataMap}) → Future<Map>
setDataConsentSet({required String gdprLevel}) → Future<String>
setExludeBundleIDArray({List<String>? exludeBundleIDList}) → Future<List>
setLogEnabled({bool logEnabled = false}) → Future<bool>
setPlacementCustomData({Map<String, Object>? placementCustomDataMap, String? placementIDStr}) → Future<String>
setPresetPlacementConfigPath({required String pathStr}) → Future<String>
setSubChannelStr({String? subchannelStr}) → Future<String>
showDebuggerUI({required String debugKey}) → Future<String>
showGDPRAuth() → Future<String>
showGDPRConsentDialog() → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited