ATNative class

Constructors

ATNative()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appIcon() → String
checkNativeAdLoadStatus({required String placementID}) → Future<Map>
createNativeSubCustomViewAttribute(double width, double height, {double x = 0, double y = 0, String backgroundColorStr = '#FFFFFF', String textColorStr = '#000000', String textAlignmentStr = 'left', double textSize = 15, bool isCustomClick = false, int cornerRadius = 0, ATCustomViewNative customViewNative = ATCustomViewNative.view, String imagePath = '', String title = ''}) → Map
createNativeSubViewAttribute(double width, double height, {double x = 0, double y = 0, String backgroundColorStr = '#FFFFFF', String textColorStr = '#000000', String textAlignmentStr = 'left', double textSize = 15, bool isCustomClick = false, int cornerRadius = 0}) → Map
cta() → String
customView() → String
desc() → String
dislike() → String
elementsView() → String
entryNativeScenario({required String placementID, required String sceneID}) → Future<bool>
getNativeValidAds({required String placementID}) → Future<String>
isAdaptiveHeight() → String
loadNativeAd({required String placementID, required Map extraMap}) → Future<String>
mainImage() → String
mainTitle() → String
nativeAdReady({required String placementID}) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parent() → String
removeNativeAd({required String placementID}) → Future<bool>
showNativeAd({required String placementID, required Map extraMap, bool isAdaptiveHeight = false}) → Future<String>
showSceneNativeAd({required String placementID, required String sceneID, required Map extraMap, bool isAdaptiveHeight = false}) → Future<String>
showSceneNativeAdWithCustomExt({required String placementID, required String sceneID, required String showCustomExt, required Map extraMap, bool isAdaptiveHeight = false}) → Future<String>
ToponNative() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited