ATNativeResponse class

Inheritance

Constructors

ATNativeResponse(NativeStatus nativeStatus, Map extraMap, String errStr, String placementID, bool isDeeplinkSuccess)
ATNativeResponse.withMap(Map map)
factory

Properties

extraMap → Map
final
hashCode → int
The hash code for this object.
no setterinherited
isDeeplinkSuccess → bool?
finalinherited
nativeStatus → NativeStatus
final
placementID → String
finalinherited
requestMessage → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited